==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core";
import { Style } from "igniteui-react-core";
import { markType, markDep, typeCast } from "igniteui-react-core";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { PropertyMetadata } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { Path } from "igniteui-react-core";
import { stringIsNullOrEmpty } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterPolylineSeries = /*@__PURE__*/ (() => {
    class ScatterPolylineSeries extends ShapeSeriesBase {
        get_e4() {
            return true;
        }
        constructor() {
            super();
            this.ab = ScatterPolylineSeries.$;
        }
        cg() {
            return new ScatterPolylineSeriesView(this);
        }
        get_uv() {
            return false;
        }
        o0(a) {
            super.o0(a);
            this.ws = a;
        }
        get_u0() {
            return false;
        }
        o8(a, b, c, d) {
            super.o8(a, b, c, d);
            switch (b) {
                case ScatterPolylineSeries.$$p[0]:
                    this.ws.cy(this.wy);
                    this.pp(false);
                    this.ol();
                    break;
                case ScatterPolylineSeries.$$p[1]:
                    this.ws.cz(this.wt);
                    this.pp(false);
                    this.ol();
                    break;
            }
        }
        wb(a) {
            let b = a;
            b.cy(this.wy);
            b.cz(this.wt);
            super.wb(a);
        }
        au(a, b) {
            let c = this.ws.c3(a, b, true);
            if (c != null) {
                return c.dataContext;
            }
            return super.au(a, b);
        }
    }
    ScatterPolylineSeries.$t = /*@__PURE__*/ markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
    ScatterPolylineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:wy:ww', [Style.$, null], 'ShapeStyleSelector:wt:wx', [StyleSelector.$, null]]);
    return ScatterPolylineSeries;
})();
/**
 * @hidden
 */
export let ScatterPolylineSeriesView = /*@__PURE__*/ (() => {
    class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
        constructor(a) {
            super(a);
        }
        au() {
            super.au();
            if (!this.q) {
                this.b6.iu = Defaults.aa;
            }
        }
        c5(a, b) {
            return this.c6(a, b, false);
        }
        cm(a, b, c) {
            super.cm(a, b, c);
            ShapeSeriesViewBase.cl(this, a, b);
        }
        ck(a, b) {
            let c = typeCast(Path.$, a);
            if (c == null) {
                return;
            }
            c.an = b;
        }
        ac(a) {
            let b = super.ac(a);
            b._fill = null;
            return b;
        }
        ab(a) {
            let b = super.ab(a);
            b._fill = null;
            return b;
        }
        cb(a) {
            return a.width >= this.b6.vh || a.height >= this.b6.vh;
        }
        getDefaultTooltipTemplate() {
            let a = "<div class='ui-chart-default-tooltip-content'><span";
            let b = this.e.a7.a$r(this.e);
            if (!stringIsNullOrEmpty(b)) {
                a += " style='color:" + b + "'";
            }
            a += ">" + this.b6.title + "</span><br/>";
            a += "</div>";
            return a;
        }
    }
    ScatterPolylineSeriesView.$t = /*@__PURE__*/ markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
    return ScatterPolylineSeriesView;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core";
import { Style } from "igniteui-react-core";
import { markType, markDep, typeCast } from "igniteui-react-core";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { ChartSelection } from "./ChartSelection";
import { List$1 } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { Path } from "igniteui-react-core";
import { stringIsNullOrEmpty } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterPolylineSeries = /*@__PURE__*/ (() => {
    class ScatterPolylineSeries extends ShapeSeriesBase {
        bj() {
            return new ScatterPolylineSeries();
        }
        get_fq() {
            return true;
        }
        constructor() {
            super();
            this.ab = ScatterPolylineSeries.$;
        }
        cr() {
            return new ScatterPolylineSeriesView(this);
        }
        get_xo() {
            return false;
        }
        qz(a) {
            super.qz(a);
            this.zm = a;
        }
        get_xt() {
            return false;
        }
        q7(a, b, c, d) {
            super.q7(a, b, c, d);
            switch (b) {
                case ScatterPolylineSeries.$$p[0]:
                    this.zm.cy(this.zs);
                    this.rp(false);
                    this.qj();
                    break;
                case ScatterPolylineSeries.$$p[1]:
                    this.zm.cz(this.zn);
                    this.rp(false);
                    this.qj();
                    break;
            }
        }
        y5(a) {
            let b = a;
            b.cy(this.zs);
            b.cz(this.zn);
            super.y5(a);
        }
        a2(a, b) {
            let c = this.zm.c3(a, b, true);
            if (c != null) {
                return c.dataContext;
            }
            return super.a2(a, b);
        }
        ak(a, b) {
            let c = new List$1(ChartSelection.$, 0);
            this.p1(a, c, b);
            return c.toArray();
        }
        p1(a, b, c) {
            this.yx(a, b, c);
        }
    }
    ScatterPolylineSeries.$t = /*@__PURE__*/ markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
    ScatterPolylineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:zs:zq', [Style.$, null], 'ShapeStyleSelector:zn:zr', [StyleSelector.$, null]]);
    return ScatterPolylineSeries;
})();
/**
 * @hidden
 */
export let ScatterPolylineSeriesView = /*@__PURE__*/ (() => {
    class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
        constructor(a) {
            super(a);
        }
        au() {
            super.au();
            if (!this.q) {
                this.b6.jo = Defaults.aa;
            }
        }
        c5(a, b) {
            return this.c6(a, b, false);
        }
        cm(a, b, c) {
            super.cm(a, b, c);
            ShapeSeriesViewBase.cl(this, a, b);
        }
        ck(a, b) {
            let c = typeCast(Path.$, a);
            if (c == null) {
                return;
            }
            c.an = b;
        }
        ac(a) {
            let b = super.ac(a);
            b._fill = null;
            return b;
        }
        ab(a) {
            let b = super.ab(a);
            b._fill = null;
            return b;
        }
        cb(a) {
            return a.width >= this.b6.ya || a.height >= this.b6.ya;
        }
        getDefaultTooltipTemplate() {
            let a = "<div class='ui-chart-default-tooltip-content'><span";
            let b = this.e.ba.a$u(this.e);
            if (!stringIsNullOrEmpty(b)) {
                a += " style='color:" + b + "'";
            }
            a += ">" + this.b6.title + "</span><br/>";
            a += "</div>";
            return a;
        }
    }
    ScatterPolylineSeriesView.$t = /*@__PURE__*/ markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
    return ScatterPolylineSeriesView;
})();
